window.Gleam.initSearch([{"doc":"gladvent","title":"gladvent","content":"# Gladvent\n\n[![Hex Package](https://img.shields.io/hexpm/v/gladvent?color=ffaff3&amp;label=%F0%9F%93%A6)](https://hex.pm/packages/gladvent)\n[![Hex.pm](https://img.shields.io/hexpm/dt/gladvent?color=ffaff3)](https://hex.pm/packages/gladvent)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3?label=%F0%9F%93%9A)](https://hexdocs.pm/gladvent/)\n[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/tanklesxl/gladvent/main)](https://github.com/tanklesxl/gladvent/actions)\n\nAn Advent Of Code runner for Gleam\n\nThis library is intended to be imported to your gleam project and used as a command runner for your advent of code project in gleam.\n\nTo add this library to your project run: `gleam add gladvent` and add `import gladvent` to your main gleam file.\n\n## Using the library\n\nThis library provides 2 options to run your advent of code solvers:\n\n1. The easy way: simply add `gladvent.main()` to the end of your project&#39;s `main` function.\n2. Create your own `Map(Int, #(fn(String) -&gt; Int, fn(String) -&gt; Int))` and pass it to `gladvent.execute`\n\n## Available commands\n\nThis project provides your application with 2 commands, `new` and `run`:\n\n- `new`: create `src/days/*.gleam` and `input/*.txt` files that correspond to the specified days\n  - format: `gleam run new a b c ...`\n  - used like `gleam run new 1 2` with days 1 and 2 creates `input/day_1.txt` and `input/day_2.txt` as well as `src/days/day_1.gleam` and `src/days/day_2.gleam`\n- `run`: run the specified days\n\n  - format: `gleam run run a b c ...`\n  - flags:\n    - `--timeout`: `gleam run run --timeout={timeout in ms} a b c ...`\n      - usage example: `gleam run run --timeout=1000 1 2` with timeout 1000 milliseconds and days 1 and 2, runs and prints the output of running the `run` function of `day_1.gleam` and `day_2.gleam`\n\n- `run all`: run all registered days\n  - format: `gleam run run all`\n  - flags:\n    - `--timeout`: `gleam run run --timeout={timeout in ms} a b c ...`\n      - usage example: `gleam run run --timeout=1000 1 2` with timeout 1000 milliseconds and days 1 and 2, runs and prints the output of running the `run` function of `day_1.gleam` and `day_2.gleam`\n\n_Note:_\n\n- the `new` command creates source files in `src/days/` and input files in the `input/` directory.\n- the `run` command expects input files to be in the `input/` directory.\n- using `gladvent.main` expects gleam day runners to be in `src/days/`\n\n## Seeing help messages\n\n- To see available subcommands: `gleam run -- --help`\n- To see help for the `run` command: `gleam run run --help`\n- To see help for the `new` command: `gleam run new --help`\n\n## General Workflow\n\nWhere X is the day you&#39;d like to add (when using `gladvent.main()`):\n\n_Note:_ this method requires all day solutions be in `src/days/` with filenames `day_X.gleam`, each solution module containing `fn pt_1(String) -&gt; Int` and a `fn pt_2(String) -&gt; Int`\n\n1. run `gleam run new X`\n2. add your input to `input/day_X.txt`\n3. add your code to `src/days/day_X.gleam`\n4. run `gleam run run X`\n\n## FAQ\n\n### Why did you make this?\n\nIt seemed fun, I like small command line utilities and I wanted a way to get advent of code done in gleam without having the additional overhead of lots of copy-pasting and connecting things to get it to run\n\n### Why does this not download the input from the advent of code website?\n\nA few reasons:\n\n1. I wanted to keep this utility as simple as possible to start with\n2. I like the advent of code website and I felt like it was a shame to circumvent visiting it, especially since you should access it to read the daily challenge. On top of that, I would like to avoid spamming the `advent of code` api if possible.\n\n### Why run as a command line utility and not just use unit tests?\n\nI thought a lot about that and I prefer the overall interactivity of a CLI better, as well as allowing for endless runs or runs with configurable timeouts. Having it run as part of `eunit` doesnt provide as much flexibility as I would like.\n","url":"index.html"},{"doc":"parse","title":"Day","content":"pub type Day =\n  Int\n\n\nSynonyms:\nparse.Day\nparse Day","url":"parse.html#Day"},{"doc":"parse","title":"day","content":"pub fn day(s: String) -&gt; Result(Int, Snag)\n\nSynonyms:\nparse.day\nparse day","url":"parse.html#day"},{"doc":"parse","title":"days","content":"pub fn days(l: List(String)) -&gt; Result(List(Int), Snag)\n\nSynonyms:\nparse.days\nparse days","url":"parse.html#days"},{"doc":"parse","title":"int","content":"pub fn int(s: String) -&gt; Result(Int, Snag)\n\nSynonyms:\nparse.int\nparse int","url":"parse.html#int"},{"doc":"parse","title":"parse","content":"","url":"parse.html"},{"doc":"runners","title":"DayRunner","content":"pub type DayRunner =\n  #(PartRunner, PartRunner)\n\n\nSynonyms:\nrunners.DayRunner\nrunners DayRunner","url":"runners.html#DayRunner"},{"doc":"runners","title":"PartRunner","content":"pub type PartRunner =\n  fn(String) -&gt; Int\n\n\nSynonyms:\nrunners.PartRunner\nrunners PartRunner","url":"runners.html#PartRunner"},{"doc":"runners","title":"RunnerMap","content":"pub type RunnerMap =\n  Map(Day, DayRunner)\n\n\nSynonyms:\nrunners.RunnerMap\nrunners RunnerMap","url":"runners.html#RunnerMap"},{"doc":"runners","title":"days_dir","content":"pub const days_dir: String = &quot;src/days/&quot;\n\nSynonyms:\nrunners.days_dir\nrunners days_dir","url":"runners.html#days_dir"},{"doc":"runners","title":"input_dir","content":"pub const input_dir: String = &quot;input/&quot;\n\nSynonyms:\nrunners.input_dir\nrunners input_dir","url":"runners.html#input_dir"},{"doc":"runners","title":"build_from_days_dir","content":"pub fn build_from_days_dir() -&gt; Result(\n  Map(Int, #(fn(String) -&gt; Int, fn(String) -&gt; Int)),\n  Snag,\n)\n\nSynonyms:\nrunners.build_from_days_dir\nrunners build_from_days_dir","url":"runners.html#build_from_days_dir"},{"doc":"runners","title":"runners","content":"","url":"runners.html"},{"doc":"cmd","title":"Timeout","content":"pub type Timeout =\n  Int\n\n\nSynonyms:\ncmd.Timeout\ncmd Timeout","url":"cmd.html#Timeout"},{"doc":"cmd","title":"Timing","content":"pub type Timing {\n  Endless\n  Ending(Timeout)\n}\n\nEndless\n\n\nEnding(Timeout)\n\n\nSynonyms:\ncmd.Timing\ncmd Timing","url":"cmd.html#Timing"},{"doc":"cmd","title":"exec","content":"pub fn exec(days: List(Int), timing: Timing, do: fn(Int) -&gt;\n    Result(a, b), other: fn(String) -&gt; b, collect: fn(\n    #(Int, Result(a, b)),\n  ) -&gt; String) -&gt; List(String)\n\nSynonyms:\ncmd.exec\ncmd exec","url":"cmd.html#exec"},{"doc":"cmd","title":"cmd","content":"","url":"cmd.html"},{"doc":"cmd/run","title":"run_all_command","content":"pub fn run_all_command(runners: Map(\n    Int,\n    #(fn(String) -&gt; Int, fn(String) -&gt; Int),\n  )) -&gt; Stub(Result(List(String), Snag))\n\nSynonyms:\ncmd/run.run_all_command\ncmd/run run_all_command","url":"cmd/run.html#run_all_command"},{"doc":"cmd/run","title":"run_command","content":"pub fn run_command(runners: Map(\n    Int,\n    #(fn(String) -&gt; Int, fn(String) -&gt; Int),\n  )) -&gt; Stub(Result(List(String), Snag))\n\nSynonyms:\ncmd/run.run_command\ncmd/run run_command","url":"cmd/run.html#run_command"},{"doc":"cmd/run","title":"cmd/run","content":"","url":"cmd/run.html"},{"doc":"ffi/file","title":"IODevice","content":"pub external type IODevice\n\n\nSynonyms:\nffi/file.IODevice\nffi/file IODevice","url":"ffi/file.html#IODevice"},{"doc":"ffi/file","title":"ensure_dir","content":"pub fn ensure_dir(dir: String) -&gt; Result(Nil, Reason)\n\nSynonyms:\nffi/file.ensure_dir\nffi/file ensure_dir","url":"ffi/file.html#ensure_dir"},{"doc":"ffi/file","title":"open_file_exclusive","content":"pub external fn open_file_exclusive(\n  s: String,\n) -&gt; Result(IODevice, Reason)\n\nSynonyms:\nffi/file.open_file_exclusive\nffi/file open_file_exclusive","url":"ffi/file.html#open_file_exclusive"},{"doc":"ffi/file","title":"write","content":"pub fn write(iod: IODevice, s: String) -&gt; Result(Nil, Reason)\n\nSynonyms:\nffi/file.write\nffi/file write","url":"ffi/file.html#write"},{"doc":"ffi/file","title":"ffi/file","content":"","url":"ffi/file.html"},{"doc":"cmd/new","title":"new_command","content":"pub fn new_command() -&gt; Stub(Result(List(String), Snag))\n\nSynonyms:\ncmd/new.new_command\ncmd/new new_command","url":"cmd/new.html#new_command"},{"doc":"cmd/new","title":"cmd/new","content":"","url":"cmd/new.html"},{"doc":"gladvent","title":"execute","content":"pub fn execute(given runners: Map(\n    Int,\n    #(fn(String) -&gt; Int, fn(String) -&gt; Int),\n  )) -&gt; Nil\n Given the daily runners, create the command tree and run the specified command\n\nSynonyms:\ngladvent.execute\ngladvent execute","url":"gladvent.html#execute"},{"doc":"gladvent","title":"main","content":"pub fn main() -&gt; Nil\n Find all runners in the project src/days/ directory and\n run either the &#39;run&#39; or &#39;new&#39; command as specified\n\nSynonyms:\ngladvent.main\ngladvent main","url":"gladvent.html#main"},{"doc":"gladvent","title":"gladvent","content":"","url":"gladvent.html"}]);